# Yacana

Task-driven multi-agent framework giving you the building blocks to create anything you wish with LLMs.  

* A simple developer-friendly API perfect for beginners in AI  
* Access to all advanced configurations for LLM experts  

Yacana is free and opensource under MIT license .  

Be ready in minutes. Start by reading the documentation [here](https://remembersoftwares.github.io/yacana/).  
